pyscicat.client.ScicatClient
============================

.. currentmodule:: pyscicat.client

.. autoclass:: ScicatClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ScicatClient.__init__
      ~ScicatClient.upload_attachment
      ~ScicatClient.upload_datablock
      ~ScicatClient.upload_raw_dataset
   
   

   
   
   